metadata(version="0.1.0")

# Originally written by Riccardo Magliocchetti.

require("ffilib")

module("gettext.py")
